@@ -14,4 +14,14 @@ register(
 register(
     id="TwoLinkArmEnv-v2",
     entry_point="gym_twolinkarm_env.envs.gravity_bottom:TwoLinkArmEnvWithGravityToBottom",
+)
+
+register(
+    id="TwoLinkArmEnv-v3",
+    entry_point="gym_twolinkarm_env.envs.normal_random:NormalRandom",
+)
+
+register(
+    id="TwoLinkArmEnv-v4",
+    entry_point="gym_twolinkarm_env.envs.gravity_random:gravityRandom",
 )
\ No newline at end of file
