@@ -99,10 +99,11 @@ class TwoLinkArmEnvWithGravity(gym.Env):
     
     def _get_reward(self):
         coord = self._get_tip_coord()
-        pos_reward = -np.sum((coord - self.target)**2)
-        vel_reward = -(math.fabs(self.state[2]) + math.fabs(self.state[3]))
+        pos_reward = np.exp(-np.sum((coord - self.target)**2))
+        # vel_reward = -(math.fabs(self.state[2]) + math.fabs(self.state[3]))
         
-        return pos_reward + vel_reward
+        return pos_reward
+        # return pos_reward + vel_reward
     
     def _get_tip_coord(self):
         p = self.physics
